@@ -72,6 +72,8 @@ struct _PersonalGprsMonPrivate
 	gboolean showResetDate;
 	gdouble version;
 	
+	gboolean isPressed;
+	
 	guint eventID;
 };
 
@@ -186,10 +188,26 @@ void personal_gprs_mon_write_settings (PersonalGprsMon *self)
 	g_free (filename);
 }
 
+void personal_gprs_mon_button_press (GtkWidget *widget, GdkEventButton *event, PersonalGprsMon *self)
+{
+	//g_warning ("%s", __PRETTY_FUNCTION__);
+	self->priv->isPressed = TRUE;
+	gtk_widget_queue_draw (GTK_WIDGET (self));
+}
+
 void personal_gprs_mon_button_release (GtkWidget *widget, GdkEventButton *event, PersonalGprsMon *self)
 {
 	//g_warning ("personal_gprs_mon_button_release");
+	self->priv->isPressed = FALSE;
 	personal_gprs_mon_update_content (self);
+	gtk_widget_queue_draw (GTK_WIDGET (self));
+}
+
+void personal_gprs_mon_leave_event (GtkWidget *widget, GdkEventCrossing *event, PersonalGprsMon *self)
+{
+	//g_warning ("%s", __PRETTY_FUNCTION__);
+	self->priv->isPressed = FALSE;
+	gtk_widget_queue_draw (GTK_WIDGET (self));
 }
 
 void personal_gprs_mon_content_create (PersonalGprsMon *self)
@@ -262,6 +280,8 @@ void personal_gprs_mon_content_create (PersonalGprsMon *self)
     gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), event, FALSE, FALSE, 0);
 	
 	g_signal_connect (event, "button-release-event", G_CALLBACK (personal_gprs_mon_button_release), self);
+	g_signal_connect (event, "button-press-event", G_CALLBACK (personal_gprs_mon_button_press), self);
+	g_signal_connect (event, "leave-notify-event", G_CALLBACK (personal_gprs_mon_leave_event), self);
 	
     gtk_widget_show_all (self->priv->homeWidget);
 	if (!self->priv->showResetDate) {
@@ -558,8 +578,13 @@ static gboolean personal_gprs_mon_expose_event (GtkWidget *widget, GdkEventExpos
 	cr = gdk_cairo_create(GDK_DRAWABLE (widget->window));
 
 	GdkColor color;
-	gtk_style_lookup_color (gtk_rc_get_style(widget), "ContentFrameColor", &color);
-	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
+	if (!self->priv->isPressed) {
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "DefaultBackgroundColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
+	} else {
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
+	}
 	
 	gint width, height, x, y;
 	gint radius = 5;
@@ -597,8 +622,13 @@ static gboolean personal_gprs_mon_expose_event (GtkWidget *widget, GdkEventExpos
 	x = widget->allocation.x;
 	y = iconSize;
 	
-	gtk_style_lookup_color (gtk_rc_get_style(widget), "DefaultBackgroundColor", &color);
-	cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
+	if (!self->priv->isPressed) {
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "DefaultBackgroundColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.5);
+	} else {
+		gtk_style_lookup_color (gtk_rc_get_style(widget), "SelectionColor", &color);
+		cairo_set_source_rgba (cr, color.red/65535.0, color.green/65335.0, color.blue/65535.0, 0.6);
+	}
 
 	cairo_move_to(cr, x + radius, y);
 	cairo_line_to(cr, x + width, y);
@@ -646,6 +676,7 @@ static void personal_gprs_mon_init (PersonalGprsMon *self)
 	//g_warning ("personal_gprs_mon_init");
 	self->priv = PERSONAL_GPRS_MON_GET_PRIVATE (self);
 	self->priv->eventID = 0;
+	self->priv->isPressed = FALSE;
 	
 	hd_home_plugin_item_set_settings (&self->parent, TRUE);
 	g_signal_connect (&self->parent, "show-settings", G_CALLBACK (personal_gprs_mon_settings), self);
